<!doctype html>
{% load static %}
{% load crispy_forms_tags %}

<html lang="en">
<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css"
          integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">

    <title>Django Slick Reporting</title>
</head>
<body>
<div class="container">
    <div class="py-5 ">
        {% block content %}

        {% endblock %}
    </div>
</div>

{% include "slick_reporting/js_resources.html" %}

{% block extrajs %}
{% endblock %}
</body>
</html>